@@ -2,7 +2,7 @@
 #
 # Author: Miquel Anglada Girotto
 # Contact: miquel [dot] anglada [at] crg [dot] eu
-# Last Update: 2021-07-24
+# Last Update: 2022-06-26
 #
 
 import numpy as np
@@ -18,27 +18,28 @@ import time
 
 
 def abs_pearson_dist(X):
-    """
-    Compute Pearson dissimilarity between columns.
+    """Compute Pearson dissimilarity between columns.
     
     Parameters
     ----------
-    X : np.array of shape (n_features, n_samples)
+    X: np.array of shape (n_features, n_samples)
         Input data.
         
     Returns
     -------
-    D : np.array of shape (n_samples, n_samples)
+    D: np.array of shape (n_samples, n_samples)
         Dissimilarity matrix.
         
     Examples
     --------
-    from robustica import abs_pearson_dist
-    from robustica.examples import make_sampledata
+    .. code-block:: python
     
-    X = make_sampledata(15, 5)
-    D = abs_pearson_dist(X)
-    D.shape
+        from robustica import abs_pearson_dist
+        from robustica.examples import make_sampledata
+
+        X = make_sampledata(15, 5)
+        D = abs_pearson_dist(X)
+        D.shape
     """
     D = np.clip((1 - np.abs(np.corrcoef(X.T))), 0, 1)
     return D
@@ -61,13 +62,15 @@ def corrmats(X, Y):
     
     Examples
     --------
-    from robustica import corrmats
-    from robustica.examples import make_sampledata
+    .. code-block:: python
+    
+        from robustica import corrmats
+        from robustica.examples import make_sampledata
 
-    X = make_sampledata(15, 5)
-    Y = make_sampledata(20, 5)
-    r = corrmats(X, Y)
-    r.shape
+        X = make_sampledata(15, 5)
+        Y = make_sampledata(20, 5)
+        r = corrmats(X, Y)
+        r.shape
     """
     assert X.shape[1] == Y.shape[1]
 
@@ -106,13 +109,15 @@ def compute_iq(X, labels, precomputed=False):
     
     Examples
     --------
-    from robustica import compute_iq
-    from robustica.examples import make_sampledata
+    .. code-block:: python
     
-    X = make_sampledata(5, 15)
-    labels = [1,1,2,1,2]
-    df = compute_iq(X, labels)
-    df
+        from robustica import compute_iq
+        from robustica.examples import make_sampledata
+
+        X = make_sampledata(5, 15)
+        labels = [1,1,2,1,2]
+        df = compute_iq(X, labels)
+        df
     """
     # is X already a correlation matrix?
     if precomputed:
@@ -140,7 +145,7 @@ class RobustICA:
     r"""
     Class to perform robust Independent Component Analysis (ICA) using different
     methods to cluster together the independent components computed via 
-    `sklearn.decomposition.FastICA`. 
+    `sklearn.decomposition.FastICA <https://scikit-learn.org/stable/modules/generated/sklearn.decomposition.FastICA.html>`_. 
     
     By default, it carries out the *Icasso* algorithm
     using aglomerative clustering with average linkage and a precomputed Pearson
@@ -155,8 +160,7 @@ class RobustICA:
                 2.2.1) (Optional) Infer and correct component signs across runs
                 2.2.2) (Optional) Reduce the feature space with PCA
             2.3) Cluster components across all S runs
-            2.4) Use clustering labels to compute the centroid of each cluster,
-                 i.e. the robust component in both S and A.
+            2.4) Use clustering labels to compute the centroid of each cluster, i.e. the robust component in both S and A.
             
     Parameters
     ----------
@@ -198,7 +202,7 @@ class RobustICA:
         Used to initialize ``w_init`` when not specified, with a
         normal distribution. Pass an int, for reproducible results
         across multiple function calls.
-        See :term:`Glossary <random_state>`.
+        See `Glossary <https://scikit-learn.org/stable/glossary.html#term-random_state>`_.
     
     robust_runs : int, default=100
         Number of times to run FastICA.
@@ -207,7 +211,7 @@ class RobustICA:
         If robust_infer_signs is True, we infer and correct the signs of components 
         across ICA runs before clustering them.
         
-    robust_method : str or callable, default="AgglomerativeClustering"
+    robust_method : str or callable, default="DBSCAN"
         Clustering class to compute robust components across ICA runs.
         If str, choose one of the following clustering algorithms from 
         `sklearn.cluster`:
@@ -288,12 +292,14 @@ class RobustICA:
     
     Examples
     --------
-    from robustica import RobustICA
-    from robustica.examples import make_sampledata
+    .. code-block:: python
     
-    X = make_sampledata(200,50)
-    rica = RobustICA(n_components=10)
-    S, A = rica.fit_transform(X)
+        from robustica import RobustICA
+        from robustica.examples import make_sampledata
+
+        X = make_sampledata(200,50)
+        rica = RobustICA(n_components=10)
+        S, A = rica.fit_transform(X)
     
     Notes
     -----
@@ -324,8 +330,8 @@ class RobustICA:
         robust_runs=100,
         robust_infer_signs=True,
         robust_dimreduce=True,
-        robust_method="AgglomerativeClustering",
-        robust_kws={"linkage": "average"},
+        robust_method="DBSCAN",
+        robust_kws={},
         robust_precompdist_func="abs_pearson_dist",
     ):
 
@@ -410,6 +416,7 @@ class RobustICA:
                 np.isin(["n_clusters", "min_samples"], list(self.robust_kws.keys()))
             )
         ):
+            print('Setting clustering defaults:', clustering_defaults[self.robust_method])
             self.robust_kws = {
                 **self.robust_kws,
                 **clustering_defaults[self.robust_method],
@@ -624,8 +631,8 @@ class RobustICA:
             A.append(A_single.mean(axis=1))
 
             # save stds
-            S_std.append(np.array(S_clust).std(axis=1))
-            A_std.append(np.array(A_clust).std(axis=1))
+            S_std.append(S_single.std(axis=1))
+            A_std.append(A_single.std(axis=1))
 
             # save summary stats
             sumstats.append(
@@ -633,8 +640,8 @@ class RobustICA:
                     {
                         "cluster_id": label,
                         "cluster_size": sum(idx),
-                        "S_mean_std": np.array(S_clust).T.std(axis=1).mean(),
-                        "A_mean_std": np.array(A_clust).T.std(axis=1).mean(),
+                        "S_mean_std": S_single.std(axis=1).mean(),
+                        "A_mean_std": A_single.std(axis=1).mean(),
                     }
                 )
             )
